#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-types
version: 0.1.0.7
id: mime-types-0.1.0.7-9c54fcb2a9f57168849ef5415f3582c2
key: mimet_EkzgPOw2pX43Kgu0zxtOKD
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/yesodweb/wai
synopsis: Basic mime-type handling types and functions
description:
    API docs and the README are available at <http://www.stackage.org/package/mime-types>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Mime
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/mime-types-0.1.0.7
library-dirs: /usr/lib/ghc-7.10.3/site-local/mime-types-0.1.0.7
data-dir: /usr/share/arm-linux-ghc-7.10.3/mime-types-0.1.0.7
hs-libraries: HSmime-types-0.1.0.7-EkzgPOw2pX43Kgu0zxtOKD
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-mime-types/html/mime-types.haddock
haddock-html: /usr/share/doc/haskell-mime-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
